@@ -1,10 +1,10 @@
 ;;; persist-text-scale.el --- Persist and restore text scale -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2025 James Cherti | https://www.jamescherti.com/contact/
+;; Copyright (C) 2025-2026 James Cherti | https://www.jamescherti.com/contact/
 
 ;; Author: James Cherti
-;; Package-Version: 1.0.3
-;; Package-Revision: 1.0.3-0-g235e37b1ca38
+;; Package-Version: 1.0.4
+;; Package-Revision: 1.0.4-0-g8098af6ba9ff
 ;; URL: https://github.com/jamescherti/persist-text-scale.el
 ;; Keywords: convenience
 ;; Package-Requires: ((emacs "26.1"))
@@ -274,8 +274,8 @@ If the buffer category is nil or no scale amount has been stored, return nil."
   (when category
     (let ((cat-data (or (cdr (assoc category persist-text-scale--data))
                         ;; TODO store this per category intead
-                        (when persist-text-scale-fallback-to-previous-scale
-                          persist-text-scale--last-text-scale-amount)
+                        ;; (when persist-text-scale-fallback-to-previous-scale
+                        ;;   persist-text-scale--last-text-scale-amount)
                         (when (integerp
                                persist-text-scale-default-text-scale-amount)
                           persist-text-scale-default-text-scale-amount))))
@@ -333,18 +333,28 @@ OBJECT can be a frame or a window."
       (when (and frame window)
         (with-selected-frame frame
           (with-selected-window window
-            (when-let* ((buffer (window-buffer)))
-              (with-current-buffer buffer
-                (when (and (buffer-base-buffer)
-                           (not persist-text-scale--indirect-buffer-initialized))
-                  (when (bound-and-true-p text-scale-mode-amount)
-                    (setq persist-text-scale--restored-amount text-scale-mode-amount)
-                    (setq persist-text-scale--persisted-amount nil)
-                    (persist-text-scale-persist))
-                  (setq persist-text-scale--indirect-buffer-initialized t))
+            (let* ((buffer (window-buffer))
+                   (base-buffer-text-scale-amount
+                    (when (and buffer
+                               (bound-and-true-p text-scale-mode-amount))
+                      text-scale-mode-amount)))
+              (when buffer
+                (with-current-buffer buffer
+                  ;; TODO Fix this part
+                  ;; (let ((base-buffer (buffer-base-buffer)))
+                  ;;   ;; Indirect buffers
+                  ;;   (when (and
+                  ;;          base-buffer
+                  ;;          (not persist-text-scale--indirect-buffer-initialized))
+                  ;;     ;; when (bound-and-true-p text-scale-mode-amount)
+                  ;;     ;; (setq persist-text-scale--restored-amount text-scale-mode-amount)
+                  ;;     ;; (setq persist-text-scale--persisted-amount nil)
+                  ;;     (text-scale-set base-buffer-text-scale-amount)
+                  ;;     (persist-text-scale-persist)
+                  ;;     (setq persist-text-scale--indirect-buffer-initialized t)))
 
-                ;; Restore all windows
-                (persist-text-scale--restore-all-windows)))))))))
+                  ;; Restore all windows
+                  (persist-text-scale--restore-all-windows))))))))))
 
 (defun persist-text-scale--text-scale-mode-hook ()
   "Hook function triggered by `text-scale-mode-hook'.
